@@ -2,7 +2,7 @@
  *
  *  PACrunner - Proxy configuration daemon
  *
- *  Copyright (C) 2010  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2010-2011  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -34,8 +34,8 @@ struct pacrunner_proxy {
 	enum pacrunner_proxy_method method;
 	char *url;
 	char *script;
-	char **servers;
-	char **excludes;
+	GList **servers;
+	GList **excludes;
 };
 
 static GList *proxy_list = NULL;
@@ -86,10 +86,10 @@ static void reset_proxy(struct pacrunner_proxy *proxy)
 	g_free(proxy->script);
 	proxy->script = NULL;
 
-	g_strfreev(proxy->servers);
+	__pacrunner_manual_destroy_servers(proxy->servers);
 	proxy->servers = NULL;
 
-	g_strfreev(proxy->excludes);
+	__pacrunner_manual_destroy_excludes(proxy->excludes);
 	proxy->excludes = NULL;
 }
 
@@ -181,11 +181,11 @@ int pacrunner_proxy_set_manual(struct pacrunner_proxy *proxy,
 	if (err < 0)
 		return err;
 
-	g_strfreev(proxy->servers);
-	proxy->servers = servers;
+	proxy->servers = __pacrunner_manual_parse_servers(servers);
+	if (proxy->servers == NULL)
+		return -EINVAL;
 
-	g_strfreev(proxy->excludes);
-	proxy->excludes = excludes;
+	proxy->excludes = __pacrunner_manual_parse_excludes(excludes);
 
 	pacrunner_proxy_enable(proxy);
 
